@@ -11,11 +11,11 @@ BSON::Decode - Decode BSON file and return a perl data structure!
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -342,6 +342,45 @@ sub document
     return $res;
 }
 
+
+sub delete_hash_deep
+{
+    my ( $hash, $allowed_keys ) = @_;
+
+    if ( ref( $hash ) && ref( $hash ) eq "ARRAY" )
+    {
+        foreach my $h ( @$hash )
+        {
+            delete_hash_deep( $h, $allowed_keys );
+        }
+    }
+    else
+    {
+        if ( ref( $hash ) eq 'HASH' )
+        {
+            foreach my $k ( keys %{$hash} )
+            {
+                if ( ( grep {$k =~ /$_/} @{$allowed_keys} ) )
+                {
+                    delete $hash->{$k};
+                    next;
+                }
+                else
+                {
+                    if ( ref( $hash->{$k} ) )
+                    {
+                        if ( ref( $hash->{$k} ) eq "HASH" || ref( $hash->{$k} ) eq "ARRAY" )
+                        {
+                            delete_hash_deep( $hash->{$k}, $allowed_keys );
+                        }
+                    }
+                }
+            }
+        }
+    }
+}
+
+
 =head1 AUTHOR
 
 DULAUNOY Fabrice, C<< <fabrice at dulaunoy.com> >>
